##################################
Lake Shore 211 Temperature Monitor
##################################

.. autoclass:: pymeasure.instruments.lakeshore.LakeShore211
    :members:
    :show-inheritance:
